Package: maybe
Title: The Maybe Monad
Version: 1.1.0
Authors@R: 
    person(given = "Andrew",
           family = "McNeil",
           role = c("aut", "cre"),
           email = "andrew.richard.mcneil@gmail.com")
Description: 
    The maybe type represents the possibility of some value or nothing. 
    It is often used instead of throwing an error or returning `NULL`.
    The advantage of using a maybe type over `NULL` is that it is both composable 
    and requires the developer to explicitly acknowledge the potential absence 
    of a value, helping to avoid the existence of unexpected behaviour.
License: MIT + file LICENSE
URL: https://github.com/armcn/maybe, https://armcn.github.io/maybe/
BugReports: https://github.com/armcn/maybe/issues
Encoding: UTF-8
LazyData: true
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.2
Imports: magrittr
Suggests: testthat (>= 3.0.0), quickcheck, covr
Config/testthat/edition: 3
Author: Andrew McNeil [aut, cre]
Maintainer: Andrew McNeil <andrew.richard.mcneil@gmail.com>
Built: R 4.4.0; ; 2024-06-01 17:16:13 UTC; unix
