# Generated by roxygen2: do not edit by hand

S3method(not_empty,data.frame)
S3method(not_empty,default)
S3method(print,maybe)
export("%>%")
export(and)
export(and_then)
export(and_then2)
export(and_then3)
export(bind)
export(filter_justs)
export(filter_map)
export(fmap)
export(from_just)
export(from_maybe)
export(is_just)
export(is_maybe)
export(is_nothing)
export(join)
export(just)
export(maybe)
export(maybe_case)
export(maybe_contains)
export(maybe_equal)
export(maybe_flatten)
export(maybe_map)
export(maybe_map2)
export(maybe_map3)
export(not_empty)
export(not_infinite)
export(not_na)
export(not_nan)
export(not_null)
export(not_undefined)
export(nothing)
export(or)
export(perhaps)
export(with_default)
importFrom(magrittr,"%>%")
